@@ -1,12 +1,15 @@
 package PDF::Builder;
 
 use strict;
-no warnings qw[ deprecated recursion uninitialized ];
+use warnings;
 
 # $VERSION defined here so developers can run PDF::Builder from git.
 # it should be automatically updated as part of the CPAN build.
-our $VERSION = '3.020'; # VERSION
-my $LAST_UPDATE = '3.020'; # manually update whenever code is changed
+our $VERSION = '3.023'; # VERSION
+our $LAST_UPDATE = '3.023'; # manually update whenever code is changed
+
+my $GrTFversion = 16;    # minimum version of Graphics::TIFF
+my $LpngVersion = 0.57;  # minimum version of Image::PNG::Libpng
 
 use Carp;
 use Encode qw(:all);
@@ -57,7 +60,7 @@ PDF::Builder - Facilitates the creation and modification of PDF files
     $page = $pdf->page();
 
     # Retrieve an existing page
-    $page = $pdf->openpage($page_number);
+    $page = $pdf->open_page($page_number);
 
     # Set the page size
     $page->mediabox('Letter');
@@ -156,15 +159,17 @@ PDF::Builder is currently being maintained by Phil M. Perry.
 
 =head2 SUPPORT
 
-Full source is on https://github.com/PhilterPaper/Perl-PDF-Builder
+The full source is on https://github.com/PhilterPaper/Perl-PDF-Builder.
 
-Bug reports are on https://github.com/PhilterPaper/Perl-PDF-Builder/issues?q=is%3Aissue+sort%3Aupdated-desc (with "bug" label), feature requests have an "enhancement" label, and general discussions (architecture, roadmap, etc.) have a "general discussion" label. Please do not use the RT.cpan system to report issues, as it is not regularly monitored.
+The release distribution is on CPAN: https://metacpan.org/pod/PDF::Builder.
 
-Release distribution is on CPAN: https://metacpan.org/pod/PDF::Builder
+Bug reports are on https://github.com/PhilterPaper/Perl-PDF-Builder/issues?q=is%3Aissue+sort%3Aupdated-desc (with "bug" label), feature requests have an "enhancement" label, and general discussions (architecture, roadmap, etc.) have a "general discussion" label.
+
+Do B<not> under I<any> circumstances open a PR (Pull Request) to report a bug. It is a waste of both your and our time and effort. Open a regular ticket (issue), and attach a Perl (.pl) program illustrating the problem, if possible. If you believe that you have a program patch, and offer to share it as a PR, we may give the go-ahead. Unsolicited PRs may be closed without further action.
 
 =head1 LICENSE
 
-This software is Copyright (c) 2017-2020 by Phil M. Perry.
+This software is Copyright (c) 2017-2021 by Phil M. Perry.
 
 This is free software, licensed under:
 
@@ -306,17 +311,17 @@ sub new {
     $self->preferences(%options);
     if (defined $options{'-outver'}) {
         if ($options{'-outver'} >= 1.4) {
-	        $self->{'pdf'}->{' version'} = $outVer = $options{'-outver'};
-	    } else {
-	        print STDERR "Invalid -outver given, or less than 1.4. Ignored.\n";
-	    }
+	    $self->{'pdf'}->{' version'} = $outVer = $options{'-outver'};
+	} else {
+	    print STDERR "Invalid -outver given, or less than 1.4. Ignored.\n";
+	}
     }
     if (defined $options{'-msgver'}) {
-	    if ($options{'-msgver'} == 0 || $options{'-msgver'} == 1) {
+        if ($options{'-msgver'} == 0 || $options{'-msgver'} == 1) {
             $msgVer = $options{'-msgver'};
-	    } else {
-	        print STDERR "Invalid -msgver given, not 0 or 1. Ignored.\n";
-	    }
+        } else {
+            print STDERR "Invalid -msgver given, not 0 or 1. Ignored.\n";
+        }
     }
     if ($options{'-file'}) {
         $self->{'pdf'}->create_file($options{'-file'});
@@ -546,7 +551,7 @@ sub open_scalar {
     if (exists $options{'-diaglevel'}) {
       $self->{'diaglevel'} = $options{'-diaglevel'};
       if ($self->{'diaglevel'} < 0 || $self->{'diaglevel'} > 5) {
-	$self->{'diaglevel'} = 2;
+        $self->{'diaglevel'} = 2;
       }
     } else {
       $self->{'diaglevel'} = 2;
@@ -699,6 +704,10 @@ enables importing of annotations (B<*EXPERIMENTAL*>).
 
 =back
 
+B<CAUTION:> Perl::Critic (tools/1_pc.pl) has started flagging the name 
+"default" as a reserved keyword in higher Perl versions. Use with caution, and
+be aware that this name I<may> have to be changed in the future.
+
 =cut
 
 sub default {
@@ -1239,7 +1248,7 @@ sub page {
     return $page;
 } # end of page()
 
-=item $page = $pdf->openpage($page_number)
+=item $page = $pdf->open_page($page_number)
 
 Returns the L<PDF::Builder::Page> object of page $page_number.
 This is similar to C<< $page = $pdf->page() >>, except that C<$page> is 
@@ -1251,14 +1260,14 @@ document.
 B<Example:>
 
     $pdf  = PDF::Builder->open('our/99page.pdf');
-    $page = $pdf->openpage(1);   # returns the first page
-    $page = $pdf->openpage(99);  # returns the last page
-    $page = $pdf->openpage(-1);  # returns the last page
-    $page = $pdf->openpage(999); # returns undef
+    $page = $pdf->open_page(1);   # returns the first page
+    $page = $pdf->open_page(99);  # returns the last page
+    $page = $pdf->open_page(-1);  # returns the last page
+    $page = $pdf->open_page(999); # returns undef
 
 =cut
 
-sub openpage {
+sub open_page {
     my $self = shift();
     my $index = shift() || 0;
     my ($page, $rotate, $media, $trans);
@@ -1279,8 +1288,7 @@ sub openpage {
         weaken $page->{' apipdf'};
         weaken $page->{' api'};
         $self->{'pdf'}->out_obj($page);
-        if ((not defined($page->{' fixed'}) or $page->{' fixed'} < 1) and 
-            ($rotate = $page->find_prop('Rotate')) ) {
+        if (($rotate = $page->find_prop('Rotate')) and not $page->{' opened'}) {
             $rotate = ($rotate->val() + 360) % 360;
 
             if ($rotate != 0 and not $self->default('nounrotate')) {
@@ -1310,7 +1318,7 @@ sub openpage {
             $trans = '';
         }
 
-        if (defined $page->{'Contents'} and (not defined($page->{' fixed'}) or $page->{' fixed'} < 1)) {
+        if (defined $page->{'Contents'} and not $page->{' opened'}) {
             $page->fixcontents();
             my $uncontent = delete $page->{'Contents'};
             my $content = $page->gfx();
@@ -1327,20 +1335,16 @@ sub openpage {
                 $content->{' stream'} .= ' Q ';
             }
 
-            ## $content->{'Length'} = PDFNum(length($content->{' stream'}));
-            # this will be fixed by the following code or content or filters
-
-            ## if we like compress we will do it now to do quicker saves
+            # if we like compress we will do it now to do quicker saves
             if ($self->{'forcecompress'} eq 'flate' || 
                 $self->{'forcecompress'} =~ m/^[1-9]\d*$/) {
-                # $content->compressFlate();
                 $content->{' stream'} = dofilter($content->{'Filter'}, $content->{' stream'});
                 $content->{' nofilt'} = 1;
                 delete $content->{'-docompress'};
                 $content->{'Length'} = PDFNum(length($content->{' stream'}));
             }
         }
-        $page->{' fixed'} = 1;
+        $page->{' opened'} = 1;
     }
 
     $self->{'pdf'}->out_obj($page);
@@ -1353,6 +1357,17 @@ sub openpage {
     return $page;
 } # end of openpage()
 
+=item $page = $pdf->openpage($page_number)
+
+B<Deprecated.> Will be removed on or after June, 2023. Use C<open_page> call
+instead.
+
+=cut
+
+sub openpage { return open_page(@_); } ## no critic
+
+# internal utility
+
 sub _walk_obj {
     my ($object_cache, $source_pdf, $target_pdf, $source_object, @keys) = @_;
 
@@ -1444,7 +1459,7 @@ sub importPageIntoForm {
     if (ref($s_idx) eq 'PDF::Builder::Page') {
         $s_page = $s_idx;
     } else {
-        $s_page = $s_pdf->openpage($s_idx);
+        $s_page = $s_pdf->open_page($s_idx);
     }
 
     $self->{'apiimportcache'} ||= {};
@@ -1479,22 +1494,22 @@ sub importPageIntoForm {
     # create a whole content stream
     ## technically it is possible to submit an unfinished
     ## (e.g., newly created) source-page, but that's nonsense,
-    ## so we expect a page fixed by openpage and die otherwise
-    die "page not processed via openpage ..." unless $s_page->{' fixed'} == 1;
+    ## so we expect a page fixed by open_page and die otherwise
+    unless ($s_page->{' opened'}) {
+        croak join(' ',
+		   "Pages may only be imported from a complete PDF.",
+		   "Save and reopen the source PDF object first.");
+    }
 
-    # since the source page comes from openpage it may already
-    # contain the required starting 'q' without the final 'Q'
-    # if forcecompress is in effect
     if (defined $s_page->{'Contents'}) {
         $s_page->fixcontents();
 
         $xo->{' stream'} = '';
-        # openpage pages only contain one stream
+        # open_page pages only contain one stream
         my ($k) = $s_page->{'Contents'}->elements();
         $k->realise();
         if ($k->{' nofilt'}) {
-            # we have a finished stream here
-            # so we unfilter
+            # we have a finished stream here, so we unfilter
             $xo->add('q', unfilter($k->{'Filter'}, $k->{' stream'}), 'Q');
         } else {
             # stream is an unfinished/unfiltered content
@@ -1560,7 +1575,7 @@ sub import_page {
     if (ref($s_idx) eq 'PDF::Builder::Page') {
         $s_page = $s_idx;
     } else {
-        $s_page = $s_pdf->openpage($s_idx);
+        $s_page = $s_pdf->open_page($s_idx);
     }
 
     if (ref($t_idx) eq 'PDF::Builder::Page') {
@@ -2191,12 +2206,12 @@ sub image_tiff {
     if ($rc == 1) {
 	# Graphics::TIFF (_GT suffix) available and to be used
         require PDF::Builder::Resource::XObject::Image::TIFF_GT;
-        $obj = PDF::Builder::Resource::XObject::Image::TIFF_GT->new($self->{'pdf'}, $file);
+        $obj = PDF::Builder::Resource::XObject::Image::TIFF_GT->new($self->{'pdf'}, $file, 'Ix'.pdfkey(), %opts);
         $self->{'pdf'}->out_obj($self->{'pages'});
     } else {
 	# Graphics::TIFF not available, or is but is not to be used
         require PDF::Builder::Resource::XObject::Image::TIFF;
-        $obj = PDF::Builder::Resource::XObject::Image::TIFF->new($self->{'pdf'}, $file);
+        $obj = PDF::Builder::Resource::XObject::Image::TIFF->new($self->{'pdf'}, $file, 'Ix'.pdfkey(), %opts);
         $self->{'pdf'}->out_obj($self->{'pages'});
 
 	if ($rc == 0 && $MSG_COUNT[0]++ == 0) {
@@ -2241,6 +2256,10 @@ sub LA_GT {
         1;
     };
     if (!defined $rc) { $rc = 0; }  # else is 1
+    if ($rc) {
+	# installed, but not up to date?
+	if ($Graphics::TIFF::VERSION < $GrTFversion) { $rc = 0; }
+    }
 
     return $rc;
 }
@@ -2348,6 +2367,10 @@ sub LA_IPL {
         1;
     };
     if (!defined $rc) { $rc = 0; }  # else is 1
+    if ($rc) {
+	# installed, but not up to date?
+	if ($Image::PNG::Libpng::VERSION < $LpngVersion) { $rc = 0; }
+    }
 
     return $rc;
 }
