@@ -5,8 +5,8 @@ use base 'PDF::Builder::Basic::PDF::Pages';
 use strict;
 use warnings;
 
-our $VERSION = '3.020'; # VERSION
-my $LAST_UPDATE = '3.017'; # manually update whenever code is changed
+our $VERSION = '3.023'; # VERSION
+our $LAST_UPDATE = '3.023'; # manually update whenever code is changed
 
 use POSIX qw(floor);
 use Scalar::Util qw(weaken);
@@ -63,7 +63,7 @@ sub new {
 
 #=item $page = PDF::Builder::Page->coerce($pdf, $pdfpage)
 #
-#Returns a page object converted from $pdfpage (called from $pdf->openpage()).
+#Returns a page object converted from $pdfpage (called from $pdf->open_page()).
 #
 #=cut
 
