@@ -3,10 +3,11 @@ package PDF::Builder::Resource::CIDFont::TrueType;
 use base 'PDF::Builder::Resource::CIDFont';
 
 use strict;
-no warnings qw[ deprecated recursion uninitialized ];
+use warnings;
+#no warnings qw[ deprecated recursion uninitialized ];
 
-our $VERSION = '3.020'; # VERSION
-my $LAST_UPDATE = '3.016'; # manually update whenever code is changed
+our $VERSION = '3.023'; # VERSION
+our $LAST_UPDATE = '3.021'; # manually update whenever code is changed
 
 use PDF::Builder::Basic::PDF::Utils;
 use PDF::Builder::Resource::CIDFont::TrueType::FontFile;
@@ -61,7 +62,7 @@ sub new {
     ## $de->{'BaseFont'} = PDFName(pdfkey().'+'.($self->fontname()).'~'.time());
     $de->{'BaseFont'} = PDFName($self->fontname());
     $de->{'DW'} = PDFNum($self->missingwidth());
-    if ($opts{'-noembed'} != 1) {
+    if (($opts{'-noembed'}||0) != 1) {
     	$des->{$self->data()->{'iscff'}? 'FontFile3': 'FontFile2'} = $ff;
     }
     unless ($self->issymbol()) {
